@@ -22,31 +22,21 @@
 #undef max
 
 CRapidDownloader::CRapidDownloader()
-    : url(REPO_MASTER)
+    : reposgzurl(REPO_MASTER)
 {
 }
 
-CRapidDownloader::~CRapidDownloader()
+void CRapidDownloader::addRemoteSdp(CSdp&& sdp)
 {
-	sdps.clear();
+	sdps.push_back(std::move(sdp));
 }
 
-void CRapidDownloader::addRemoteSdp(CSdp& sdp)
+bool CRapidDownloader::list_compare(const CSdp& first, const CSdp& second)
 {
-	sdps.push_back(sdp);
-}
-
-bool CRapidDownloader::list_compare(CSdp& first, CSdp& second)
-{
-	std::string name1;
-	std::string name2;
-	name1.clear();
-	name2.clear();
-	name1 = (first.getShortName());
-	name2 = (second.getShortName());
-	unsigned int len;
-	len = std::min(name1.size(), name2.size());
-	for (unsigned int i = 0; i < len; i++) {
+	const std::string name1 = first.getShortName();
+	const std::string name2 = second.getShortName();
+	const unsigned len = std::min(name1.size(), name2.size());
+	for (unsigned i = 0; i < len; i++) {
 		if (tolower(name1[i]) < tolower(name2[i])) {
 			return true;
 		}
@@ -65,13 +55,14 @@ bool CRapidDownloader::download_name(IDownload* download, int reccounter,
 
 	for (CSdp& sdp : sdps) {
 		if (!match_download_name(sdp.getName(),
-					 name.empty() ? download->name : name))
+					 name.empty() ? download->name : name)) {
 			continue;
+		}
 
-		if (downloaded.find(sdp.getMD5()) !=
-		    downloaded.end()) // already downloaded, skip (i.e. stable entries are
-				      // twice in versions.gz)
+		// already downloaded, skip (i.e. stable entries are // twice in versions.gz)
+		if (downloaded.find(sdp.getMD5()) != downloaded.end()) {
 			continue;
+		}
 		downloaded.insert(sdp.getMD5());
 
 		LOG_INFO ("[Download] %s", sdp.getName().c_str());
@@ -79,8 +70,9 @@ bool CRapidDownloader::download_name(IDownload* download, int reccounter,
 		if (!sdp.download(download)) {
 			return false;
 		}
-		if (sdp.getDepends().empty())
+		if (sdp.getDepends().empty()) {
 			continue;
+		}
 		if (!download_name(download, reccounter + 1, sdp.getDepends())) {
 			return false;
 		}
@@ -95,7 +87,7 @@ bool CRapidDownloader::search(std::list<IDownload*>& result,
 	LOG_DEBUG("%s", name.c_str());
 	updateRepos(name);
 	sdps.sort(list_compare);
-	for (CSdp& sdp : sdps) {
+	for (const CSdp& sdp : sdps) {
 		if (match_download_name(sdp.getShortName(), name) ||
 		    (match_download_name(sdp.getName(), name))) {
 			IDownload* dl =
@@ -121,18 +113,13 @@ bool CRapidDownloader::download(IDownload* download, int /*max_parallel*/)
 bool CRapidDownloader::match_download_name(const std::string& str1,
 					   const std::string& str2)
 {
-	if (str2 == "")
-		return true;
-	if (str1 == str2)
-		return true;
-	if (str2 == "*")
-		return true;
+	return str2 == "" || str1 == str2 || str2 == "*";
 	// FIXME: add regex support for win32
 	/*
   #ifndef WIN32
           regex_t regex;
           if (regcomp(&regex, str2.c_str(), 0)==0) {
-                  int res=regexec(&regex, str1.c_str(),0, NULL, 0 );
+                  int res=regexec(&regex, str1.c_str(),0, nullptr, 0 );
                   regfree(&regex);
                   if (res==0) {
                           return true;
@@ -140,14 +127,14 @@ bool CRapidDownloader::match_download_name(const std::string& str1,
           }
   #endif
   */
-	return false;
 }
 
 bool CRapidDownloader::setOption(const std::string& key,
 				 const std::string& value)
 {
+	LOG_INFO("setOption %s = %s", key.c_str(), value.c_str());
 	if (key == "masterurl") {
-		url = value;
+		reposgzurl = value;
 		return true;
 	}
 	if (key == "forceupdate") {
@@ -156,91 +143,97 @@ bool CRapidDownloader::setOption(const std::string& key,
 	return IDownloader::setOption(key, value);
 }
 
-void CRapidDownloader::downloadbyname(const std::string& name)
+bool CRapidDownloader::UpdateReposGZ()
 {
 	std::string tmp;
-	if (!urlToPath(name, tmp)) {
+	if (!urlToPath(reposgzurl, tmp)) {
 		LOG_ERROR("Invalid path: %s", tmp.c_str());
-		return;
+		return false;
 	}
 	path = fileSystem->getSpringDir() + PATH_DELIMITER + "rapid" +
 	       PATH_DELIMITER + tmp;
 	fileSystem->createSubdirs(CFileSystem::DirName(path));
-	LOG_DEBUG("%s", name.c_str());
+	LOG_DEBUG("%s", reposgzurl.c_str());
 	// first try already downloaded file, as repo master file rarely changes
 	if ((fileSystem->fileExists(path)) && (!fileSystem->isOlder(path, REPO_MASTER_RECHECK_TIME)) && parse())
-		return;
+		return true;
 	IDownload dl(path);
-	dl.addMirror(name);
-	httpDownload->download(&dl);
-	parse();
+	dl.addMirror(reposgzurl);
+	return httpDownload->download(&dl) && parse();
 }
 
-bool CRapidDownloader::parse()
+static bool ParseFD(FILE* f, const std::string& path, std::list<CRepo>& repos, CRapidDownloader* rapid)
 {
-	FILE* f = fileSystem->propen(path, "rb");
-	if (f == NULL) {
-		return false;
-	}
+	repos.clear();
 	gzFile fp = gzdopen(fileno(f), "rb");
 	if (fp == Z_NULL) {
-		fclose(f);
 		LOG_ERROR("Could not open %s", path.c_str());
 		return false;
 	}
 	char buf[IO_BUF_SIZE];
-	repos.clear();
 	int i = 0;
 	while (gzgets(fp, buf, sizeof(buf)) != Z_NULL) {
 		const std::string line = buf;
 		const std::vector<std::string> items = tokenizeString(line, ',');
 		if (items.size() <= 2) { // create new repo from url
-			gzclose(fp);
-			fclose(f);
 			LOG_ERROR("Parse Error %s, Line %d: %s", path.c_str(), i, buf);
+			gzclose(fp);
 			return false;
 		}
 		i++;
-		CRepo repotmp = CRepo(items[1], items[0], this);
+		CRepo repotmp = CRepo(items[1], items[0], rapid);
 		repos.push_back(repotmp);
 	}
 	gzclose(fp);
-	fclose(f);
+	if (i <= 0) {
+		LOG_ERROR("Broken %s: %d", path.c_str(), i);
+		return false;
+	}
 	LOG_INFO("Found %d repos in %s", repos.size(), path.c_str());
 	return true;
 }
 
+bool CRapidDownloader::parse()
+{
+	FILE* f = fileSystem->propen(path, "rb");
+	if (f == nullptr) {
+		return false;
+	}
+
+	const bool res = ParseFD(f, path, repos, this);
+	fclose(f);
+	if (!res) {
+		CFileSystem::removeFile(path);
+	}
+
+	return res;
+}
+
 bool CRapidDownloader::updateRepos(const std::string& searchstr)
 {
-	std::string::size_type pos = searchstr.find(':');
-	std::string tag;
+	const std::string::size_type pos = searchstr.find(':');
 	if (pos != std::string::npos) { // a tag is found, set it
-		tag = searchstr.substr(0, pos);
+		const std::string tag = searchstr.substr(0, pos);
+		// FIXME: tag isn't used??
 	}
 
 	LOG_DEBUG("%s", "Updating repos...");
-	downloadbyname(url);
+	if (!UpdateReposGZ()) {
+		return false;
+	}
 
 	std::list<IDownload*> dls;
 	std::list<CRepo*> usedrepos;
 	for (CRepo& repo : repos) {
 		IDownload* dl = new IDownload();
-		if (repo.getDownload(*dl)) {
-			if (repo.getShortName() == tag) { // matching repo exists, update this
-							  // only
-				IDownloader::freeResult(dls);
-				usedrepos.clear();
-				usedrepos.push_back(&repo);
-				dls.push_back(dl);
-				break;
-			}
-			usedrepos.push_back(&repo);
-			dls.push_back(dl);
-		} else {
+		if (!repo.getDownload(*dl)) {
 			delete dl;
+			continue;
 		}
+		usedrepos.push_back(&repo);
+		dls.push_back(dl);
 	}
-
+	LOG_DEBUG("Downloading ...");
 	httpDownload->download(dls);
 	for (CRepo* repo : usedrepos) {
 		repo->parse();
