@@ -9,7 +9,6 @@
 class HashMD5 : public IHash
 {
 public:
-	HashMD5();
 	void Init();
 	void Final();
 	void Update(const char* data, const int size);
@@ -21,7 +20,7 @@ public:
 	int getSize() const;
 
 private:
-	MD5_CTX mdContext;
+	MD5_CTX mdContext = {};
 };
 
 #endif
