@@ -9,26 +9,28 @@
 #include <vector>
 #include "IArchive.h"
 
-
 /**
  * A zip compressed, single-file archive.
  */
-class CZipArchive: public IArchive
+class CZipArchive : public IArchive
 {
 public:
 	explicit CZipArchive(const std::string& archiveName);
 	virtual ~CZipArchive();
 
-	virtual bool IsOpen();
+	virtual bool IsOpen() const;
 
 	virtual unsigned int NumFiles() const;
-	virtual void FileInfo(unsigned int fid, std::string& name, int& size, int& mode) const;
+	virtual void FileInfo(unsigned int fid, std::string& name, int& size,
+			      int& mode) const;
 	virtual unsigned int GetCrc32(unsigned int fid);
 	bool GetFile(unsigned int fid, std::vector<unsigned char>& buffer);
+
 protected:
 	unzFile zip;
 
-	struct FileData {
+	struct FileData
+	{
 		unz_file_pos fp;
 		int size;
 		std::string origName;
@@ -37,7 +39,8 @@ protected:
 	};
 	std::vector<FileData> fileData;
 
-//	virtual bool GetFileImpl(unsigned int fid, std::vector<boost::uint8_t>& buffer);
+	//	virtual bool GetFileImpl(unsigned int fid, std::vector<boost::uint8_t>&
+	// buffer);
 };
 
 #endif // _ZIP_ARCHIVE_H
