@@ -87,7 +87,7 @@ void show_results(int count)
 
 bool download(DownloadEnum::Category cat, const char* name)
 {
-	int count = DownloadSearch(cat, name);
+	const int count = DownloadSearch(cat, name);
 	if (count <= 0) {
 		LOG_DEBUG("Couldn't find %s", name);
 		return false;
@@ -101,7 +101,7 @@ bool download(DownloadEnum::Category cat, const char* name)
 
 bool search(DownloadEnum::Category cat, const char* name)
 {
-	int count = DownloadSearch(cat, name);
+	const int count = DownloadSearch(cat, name);
 	if (count <= 0) {
 		LOG_ERROR("Couldn't find %s", name);
 		return false;
@@ -120,7 +120,6 @@ int main(int argc, char** argv)
 	if (argc < 2)
 		show_help(argv[0]);
 
-	bool res = true;
 	bool removeinvalid = false;
 	bool fsset = false;
 
@@ -149,24 +148,33 @@ int main(int argc, char** argv)
 		DownloadSetConfig(CONFIG_FILESYSTEM_WRITEPATH, "");
 	}
 
-	DownloadInit();
 
+	DownloadInit();
 	optind = 1; // reset argv scanning
+	bool hasdownload = false; // a download is done
+	bool res = true;
 	while (true) {
 		const int c = getopt_long(argc, argv, "", long_options, nullptr);
 		if (c == -1)
 			break;
 		switch (c) {
 			case RAPID_DOWNLOAD: {
+				hasdownload = true;
 				download(DownloadEnum::CAT_GAME, optarg);
 				break;
 			}
 			case RAPID_VALIDATE: {
-				DownloadRapidValidate(removeinvalid);
+				if (!DownloadRapidValidate(removeinvalid)) {
+					LOG_ERROR("Validation of the rapid pool failed");
+					res = false;
+				}
 				break;
 			}
 			case FILESYSTEM_DUMPSDP: {
-				DownloadDumpSDP(optarg);
+				if (!DownloadDumpSDP(optarg)) {
+					LOG_ERROR("Error dumping sdp");
+					res = false;
+				}
 				break;
 			}
 			case FILESYSTEM_VALIDATESDP: {
@@ -174,6 +182,7 @@ int main(int argc, char** argv)
 				break;
 			}
 			case DOWNLOAD_MAP: {
+				hasdownload = true;
 				if (!download(DownloadEnum::CAT_MAP, optarg)) {
 					LOG_ERROR("No map found for %s", optarg);
 					res = false;
@@ -181,6 +190,7 @@ int main(int argc, char** argv)
 				break;
 			}
 			case DOWNLOAD_GAME: {
+				hasdownload = true;
 				if (!download(DownloadEnum::CAT_GAME, optarg)) {
 					LOG_ERROR("No game found for %s", optarg);
 					res = false;
@@ -191,6 +201,7 @@ int main(int argc, char** argv)
 				show_version();
 				break;
 			case DOWNLOAD_ENGINE: {
+				hasdownload = true;
 				if (!download(DownloadEnum::CAT_ENGINE, optarg)) {
 					LOG_ERROR("No engine version found for %s", optarg);
 					res = false;
@@ -199,6 +210,7 @@ int main(int argc, char** argv)
 			}
 			case HTTP_SEARCH: {
 				LOG_ERROR("Not implemented");
+				res = false;
 				break;
 			}
 			case HELP: {
@@ -209,6 +221,7 @@ int main(int argc, char** argv)
 	}
 	if (optind < argc) {
 		while (optind < argc) {
+			hasdownload = true;
 			if (!download(DownloadEnum::CAT_NONE, argv[optind])) {
 				LOG_ERROR("No file found for %s", argv[optind]);
 				res = false;
@@ -216,14 +229,15 @@ int main(int argc, char** argv)
 			optind++;
 		}
 	}
-	const int dlres = DownloadStart();
-	if (dlres > 1) {
-		LOG_ERROR("Error occurred while downloading: %d", dlres);
-	} else {
-		LOG_INFO("Download complete!");
+	if (!hasdownload) {
+		return !res;
 	}
+	const int dlres = DownloadStart();
 	DownloadShutdown();
-	if (res)
-		return 0;
-	return 1;
+	if (dlres == 0) {
+		LOG_INFO("Download complete!");
+	} else {
+		LOG_ERROR("Error occurred while downloading: %d", dlres);
+	}
+	return dlres;
 }
