@@ -231,12 +231,17 @@ void updatelistener(int downloaded, int filesize)
 		m_progress = new PrDownloader::DownloadProgress();
 
 	static struct timespec lastupdate = {0, 0};
-	struct timespec now;
+	struct timespec now = {0, 0};
 	clock_gettime(CLOCK_MONOTONIC, &now);
+
+	// rate limit
 	if (((double)now.tv_sec + 1.0e-9 * now.tv_nsec) - ((double)lastupdate.tv_sec + 1.0e-9 * lastupdate.tv_nsec) < 0.2f) {
-		//rate limit events
-		return;
+		// always log 100%
+		if (downloaded != filesize) {
+			return;
+		}
 	}
+
 	lastupdate.tv_nsec = now.tv_nsec;
 	lastupdate.tv_sec = now.tv_sec;
 
