@@ -25,6 +25,7 @@
 #include "gui/battlelist/battlelisttab.h"
 #include "gui/chatpanel.h"
 #include "gui/connectwindow.h"
+#include "gui/crashreporterdialog.h"
 #include "gui/customdialogs.h"
 #include "gui/hosting/battleroomtab.h"
 #include "gui/hosting/mainjoinbattletab.h"
@@ -59,9 +60,9 @@
 
 
 SLCONFIG("/General/AutoUpdate", true, "Determines if springlobby should check for updates on startup");
-SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_BATTLELIST, "which tab to show on startup");
+SLCONFIG("/GUI/StartTab", (long)MainWindow::PAGE_MULTIPLAYER, "which tab to show on startup");
 SLCONFIG("/Chat/BroadcastEverywhere", true, "setting to spam the server messages in all channels");
-SLCONFIG("/Server/Autoconnect", false, "Connect to server on startup");
+SLCONFIG("/Server/Autoconnect", true, "Connect to server on startup");
 
 
 static unsigned int s_reconnect_delay_ms = 6 * 1000; //initial reconnect delay
@@ -76,8 +77,8 @@ Ui& ui()
 
 Ui::Ui()
     : m_serv(0)
-    , m_main_win(0)
-    , m_con_win(0)
+    , m_main_win(nullptr)
+    , m_con_win(nullptr)
     , m_first_update_trigger(true)
     , m_connecting(false)
     , m_connect_retries(0)
@@ -108,30 +109,27 @@ ChatPanel* Ui::GetActiveChatPanel()
 MainWindow& Ui::mw()
 {
 	assert(wxThread::IsMain());
-	ASSERT_LOGIC(m_main_win != 0, "m_main_win = 0");
+	ASSERT_LOGIC(m_main_win != nullptr, "m_main_win = 0");
 	return *m_main_win;
 }
 
 const MainWindow& Ui::mw() const
 {
-	ASSERT_LOGIC(m_main_win != 0, "m_main_win = 0");
+	ASSERT_LOGIC(m_main_win != nullptr, "m_main_win = 0");
 	return *m_main_win;
 }
 
 
 bool Ui::IsMainWindowCreated() const
 {
-	if (m_main_win == 0)
-		return false;
-	else
-		return true;
+	return m_main_win != nullptr;
 }
 
 
 //! @brief Shows the main window on screen
 void Ui::ShowMainWindow()
 {
-	ASSERT_LOGIC(m_main_win != 0, "m_main_win = 0");
+	ASSERT_LOGIC(m_main_win != nullptr, "m_main_win = 0");
 	mw().Show(true);
 
 	SlPaths::ValidatePaths();
@@ -146,9 +144,9 @@ void Ui::ShowConnectWindow()
 	if (ServerManager::Instance()->IsConnected()) {
 		return;
 	}
-	if (m_con_win == 0) {
-		ASSERT_LOGIC(m_main_win != 0, "m_main_win = 0");
-		m_con_win = new ConnectWindow(m_main_win, *this);
+	if (m_con_win == nullptr) {
+		ASSERT_LOGIC(m_main_win != nullptr, "m_main_win = 0");
+		m_con_win = new ConnectWindow(m_main_win);
 	}
 	m_con_win->CenterOnParent();
 	m_con_win->Show(true);
@@ -184,10 +182,9 @@ bool Ui::IsSpringRunning() const
 void Ui::Quit()
 {
 	ServerManager::Instance()->DisconnectFromServer();
-	if (m_con_win != 0) {
-		m_con_win->Close();
-		delete m_con_win;
-		m_con_win = NULL;
+	if (m_con_win != nullptr) {
+		m_con_win->Destroy();
+		m_con_win = nullptr;
 	}
 }
 
@@ -201,6 +198,11 @@ bool Ui::Ask(const wxString& heading, const wxString& question) const
 	return (answer == wxYES);
 }
 
+int Ui::AskCrashReporter(const wxString& heading, const wxString& question, const wxString& filePath) const
+{
+	return CrashReporterDialog::RunCrashReporterDialog(m_main_win, heading, question, filePath);
+}
+
 //! cannot be const because parent window cannot be const
 bool Ui::AskPassword(const wxString& heading, const wxString& message, wxString& password)
 {
@@ -221,7 +223,7 @@ bool Ui::AskText(const wxString& heading, const wxString& question, wxString& an
 
 void Ui::ShowMessage(const wxString& heading, const wxString& message) const
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	serverMessageBox(SL_MAIN_ICON, message, heading, wxOK);
 }
@@ -278,8 +280,10 @@ void Ui::OnConnected(IServer& server, const wxString& server_name, const wxStrin
 {
 	slLogDebugFunc("");
 
-	delete m_con_win;
-	m_con_win = 0;
+	if (m_con_win != nullptr) {
+		m_con_win->Destroy();
+		m_con_win = nullptr;
+	}
 	m_connect_retries = 10;
 
 	if (server.panel != nullptr)
@@ -291,7 +295,7 @@ void Ui::OnConnected(IServer& server, const wxString& server_name, const wxStrin
 
 void Ui::OnLoggedIn()
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetChatTab().OnLoggedIn();
 	mw().GetBattleListTab().SortBattleList();
@@ -302,7 +306,7 @@ void Ui::OnDisconnected(IServer& server, bool wasonline)
 	Start(s_reconnect_delay_ms, true);
 	m_connecting = false;
 
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	slLogDebugFunc("");
 
@@ -331,9 +335,8 @@ void Ui::OnDisconnected(IServer& server, bool wasonline)
 void Ui::OnJoinedChannelSuccessful(Channel& chan, bool doFocus)
 {
 	slLogDebugFunc("");
-	if (m_main_win == NULL) {
+	if (m_main_win == nullptr)
 		return;
-	}
 	mw().OpenChannelChat(chan, doFocus);
 }
 
@@ -363,7 +366,7 @@ void Ui::OnChannelList(const wxString& channel, const int& numusers)
 
 void Ui::OnUserOnline(User& user)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetChatTab().OnUserConnected(user);
 }
@@ -371,7 +374,7 @@ void Ui::OnUserOnline(User& user)
 
 void Ui::OnUserOffline(User& user)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetChatTab().OnUserDisconnected(user);
 	if (user.panel != nullptr) {
@@ -383,7 +386,7 @@ void Ui::OnUserOffline(User& user)
 
 void Ui::OnUserStatusChanged(User& user)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	for (int i = 0; i < m_serv->GetNumChannels(); i++) {
 		Channel& chan = m_serv->GetChannel(i);
@@ -399,7 +402,8 @@ void Ui::OnUserStatusChanged(User& user)
 	try {
 		ChatPanel& server = mw().GetChatTab().ServerChat();
 		server.UserStatusUpdated(user);
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 }
 
@@ -419,12 +423,13 @@ void Ui::OnMotd(IServer& server, const wxString& message)
 
 void Ui::OnServerBroadcast(IServer& /*server*/, const wxString& message)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetChatTab().BroadcastMessage(message);
 	try { // send it to battleroom too
 		mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().StatusMessage(message);
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 }
 
@@ -446,7 +451,8 @@ void Ui::OnServerMessage(IServer& server, const wxString& message)
 		}
 		try { // send it to battleroom too
 			mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().StatusMessage(message);
-		} catch (...) {
+		} catch (const std::exception& e) {
+			wxLogWarning(_T("Exception: %s"), e.what());
 		}
 	}
 }
@@ -454,7 +460,7 @@ void Ui::OnServerMessage(IServer& server, const wxString& message)
 
 void Ui::OnUserSaid(User& chan, User& user, const wxString& message)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	if (chan.panel == nullptr) {
 		mw().OpenPrivateChat(chan);
@@ -464,7 +470,7 @@ void Ui::OnUserSaid(User& chan, User& user, const wxString& message)
 
 void Ui::OnUserSaidEx(User& chan, User& user, const wxString& action)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	if (chan.panel == 0) {
 		mw().OpenPrivateChat(chan);
@@ -474,7 +480,7 @@ void Ui::OnUserSaidEx(User& chan, User& user, const wxString& action)
 
 void Ui::OnBattleOpened(IBattle& battle)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetBattleListTab().AddBattle(battle);
 	try {
@@ -485,14 +491,15 @@ void Ui::OnBattleOpened(IBattle& battle)
 				chan.panel->UserStatusUpdated(user);
 			}
 		}
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 }
 
 
 void Ui::OnBattleClosed(IBattle& battle)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetBattleListTab().RemoveBattle(battle);
 	try {
@@ -503,7 +510,8 @@ void Ui::OnBattleClosed(IBattle& battle)
 			}
 			mw().GetJoinTab().LeaveCurrentBattle();
 		}
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 
 	for (auto userpair : battle.GetUsers()) {
@@ -523,7 +531,7 @@ void Ui::OnBattleClosed(IBattle& battle)
 
 void Ui::OnUserJoinedBattle(IBattle& battle, User& user)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetBattleListTab().UpdateBattle(battle);
 
@@ -532,7 +540,8 @@ void Ui::OnUserJoinedBattle(IBattle& battle, User& user)
 			mw().GetJoinTab().GetBattleRoomTab().OnUserJoined(user);
 			OnBattleInfoUpdated(battle, wxEmptyString);
 		}
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 
 	for (int i = 0; i < m_serv->GetNumChannels(); i++) {
@@ -547,7 +556,7 @@ void Ui::OnUserJoinedBattle(IBattle& battle, User& user)
 void Ui::OnUserLeftBattle(IBattle& battle, User& user, bool isbot)
 {
 	assert(wxThread::IsMain());
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	user.SetSideiconIndex(-1);    //just making sure he's not running around with some icon still set
 	user.BattleStatus().side = 0; // and reset side, so after rejoin we don't potentially stick with a num higher than avail
@@ -558,10 +567,12 @@ void Ui::OnUserLeftBattle(IBattle& battle, User& user, bool isbot)
 			OnBattleInfoUpdated(battle, wxEmptyString);
 			if (&user == &m_serv->GetMe()) {
 				mw().GetJoinTab().LeaveCurrentBattle();
-				mw().ShowTab(MainWindow::PAGE_BATTLELIST);
+				mw().GetBattleListTab().LeftBattle();
+				mw().ShowTab(MainWindow::PAGE_MULTIPLAYER);
 			}
 		}
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 	if (isbot)
 		return;
@@ -575,7 +586,7 @@ void Ui::OnUserLeftBattle(IBattle& battle, User& user, bool isbot)
 
 void Ui::OnBattleInfoUpdated(IBattle& battle, const wxString& Tag)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetBattleListTab().UpdateBattle(battle);
 	if (mw().GetJoinTab().GetCurrentBattle() == &battle) {
@@ -585,9 +596,10 @@ void Ui::OnBattleInfoUpdated(IBattle& battle, const wxString& Tag)
 
 void Ui::OnJoinedBattle(IBattle& battle)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetJoinTab().JoinBattle(battle);
+	mw().GetBattleListTab().JoinBattle(battle);
 	mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
 	if (battle.GetNatType() != NAT_None) {
 		wxLogWarning(_T("joining game with NAT transversal"));
@@ -597,7 +609,7 @@ void Ui::OnJoinedBattle(IBattle& battle)
 
 void Ui::OnHostedBattle(IBattle& battle)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	mw().GetJoinTab().HostBattle(battle);
 	mw().ShowTab(MainWindow::PAGE_BATTLEROOM);
@@ -606,9 +618,8 @@ void Ui::OnHostedBattle(IBattle& battle)
 
 void Ui::OnUserBattleStatus(User& user)
 {
-	if (m_main_win == 0) {
+	if (m_main_win == nullptr)
 		return;
-	}
 	if (m_serv == 0 || !m_serv->IsOnline()) {
 		return;
 	}
@@ -624,29 +635,28 @@ void Ui::OnUserBattleStatus(User& user)
 
 void Ui::OnBattleTopic(IBattle& /*battle*/, const wxString& who, const wxString& msg)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	try {
 		mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().SetTopic(who, msg);
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 }
 
 void Ui::OnSaidBattle(IBattle& /*battle*/, const wxString& nick, const wxString& msg)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	try {
 		mw().GetJoinTab().GetBattleRoomTab().GetChatPanel().Said(nick, msg);
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 }
 
-void Ui::OnSpringTerminated(wxCommandEvent& data)
+void Ui::OnSpringTerminated(wxCommandEvent&)
 {
-	const int exit_code = data.GetInt();
-	wxLogInfo("Exiting with %d", exit_code);
-
 	if (!m_serv)
 		return;
 
@@ -660,7 +670,8 @@ void Ui::OnSpringTerminated(wxCommandEvent& data)
 			battle->SetIsLocked(false);
 			battle->SendHostInfo(IBattle::HI_Locked);
 		}
-	} catch (assert_exception&) {
+	} catch (const assert_exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 }
 
@@ -680,7 +691,7 @@ void Ui::OnAcceptAgreement(const wxString& agreement)
 
 void Ui::OnRing(const wxString& from)
 {
-	if (m_main_win == 0)
+	if (m_main_win == nullptr)
 		return;
 	m_main_win->RequestUserAttention();
 
@@ -717,11 +728,13 @@ void Ui::ReloadPresetList()
 {
 	try {
 		mw().GetSPTab().ReloadPresetList();
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 	try {
 		mw().GetJoinTab().ReloadPresetList();
-	} catch (...) {
+	} catch (const std::exception& e) {
+		wxLogWarning(_T("Exception: %s"), e.what());
 	}
 }
 
@@ -841,8 +854,8 @@ void Ui::CheckForUpdates(bool is_interactive)
 			customMessageBox(SL_MAIN_ICON, errorMsg, _("Updater error."));
 			OpenWebBrowser(_T("https://github.com/springlobby/springlobby/wiki/Install#Windows_Binary"));
 			OpenWebBrowser(TowxString(GetDownloadUrl(latestVersion)));
-		} catch (...) {
-			wxLogError("Unknown exception");
+		} catch (const std::exception& e) {
+			wxLogError(_T("Exception: %s"), e.what());
 		}
 #else
 		message += _("Please update to the latest version before reporting bugs.");
@@ -870,7 +883,7 @@ void Ui::OnQuit(wxCommandEvent& /*data*/)
 
 void Ui::Notify()
 {
-	if (m_serv->IsConnected() || (m_con_win != NULL && m_con_win->IsVisible())) {
+	if (m_serv->IsConnected() || (m_con_win != nullptr && m_con_win->IsVisible())) {
 		Stop();
 	} else {
 		ServerManager::Instance()->ReconnectToServer();
@@ -879,16 +892,16 @@ void Ui::Notify()
 
 void Ui::OnRegistrationAccepted(const wxString& user, const wxString& pass)
 {
-	if (m_con_win == 0) {
-		m_con_win = new ConnectWindow(m_main_win, *this);
+	if (m_con_win == nullptr) {
+		m_con_win = new ConnectWindow(m_main_win);
 	}
 	m_con_win->OnRegistrationAccepted(user, pass);
 }
 
 void Ui::OnRegistrationDenied(const wxString& reason)
 {
-	if (m_con_win == 0) {
-		m_con_win = new ConnectWindow(m_main_win, *this);
+	if (m_con_win == nullptr) {
+		m_con_win = new ConnectWindow(m_main_win);
 	}
 	m_con_win->OnRegistrationDenied(reason);
 	ServerManager::Instance()->DisconnectFromServer();
@@ -896,8 +909,8 @@ void Ui::OnRegistrationDenied(const wxString& reason)
 
 void Ui::OnLoginDenied(const std::string& reason)
 {
-	if (m_con_win == 0) {
-		m_con_win = new ConnectWindow(m_main_win, *this);
+	if (m_con_win == nullptr) {
+		m_con_win = new ConnectWindow(m_main_win);
 	}
 	m_con_win->OnLoginDenied(TowxString(reason));
 	ServerManager::Instance()->DisconnectFromServer();
@@ -930,9 +943,9 @@ bool Ui::NeedsDownload(const IBattle* battle, bool uiprompt, DownloadEnum::Categ
 		stodl.append("- map " + battle->GetHostMapName() + "\n");
 		todl.push_back(std::make_pair(DownloadEnum::CAT_MAP, battle->GetHostMapName()));
 	}
-	if (requested(cat, DownloadEnum::CAT_GAME) && !battle->GameExists(false) && !battle->GetHostGameName().empty()) {
-		stodl.append("- game " + battle->GetHostGameName() + "\n");
-		todl.push_back(std::make_pair(DownloadEnum::CAT_GAME, battle->GetHostGameName()));
+	if (requested(cat, DownloadEnum::CAT_GAME) && !battle->GameExists(false) && !battle->GetHostGameNameAndVersion().empty()) {
+		stodl.append("- game " + battle->GetHostGameNameAndVersion() + "\n");
+		todl.push_back(std::make_pair(DownloadEnum::CAT_GAME, battle->GetHostGameNameAndVersion()));
 	}
 
 
